@@ -31,13 +31,13 @@ sub redacted {
 sub hidden {
     return qw(
         KinoSearch::Analysis::Inversion
-        KinoSearch::FieldType::Int32Type
-        KinoSearch::FieldType::Int64Type
-        KinoSearch::FieldType::Float32Type
-        KinoSearch::FieldType::Float64Type
-        KinoSearch::Obj::Num
+        KinoSearch::Object::Num
+        KinoSearch::Plan::Int32Type
+        KinoSearch::Plan::Int64Type
+        KinoSearch::Plan::Float32Type
+        KinoSearch::Plan::Float64Type
         KinoSearch::Redacted
-        KinoSearch::Test::Obj::TestCharBuf
+        KinoSearch::Test::Object::TestCharBuf
         KinoSearch::Test::TestUtils
         KinoSearch::Test::USConSchema
         KinoSearch::Util::BitVector
