@@ -20,7 +20,7 @@
 #include "KinoSearch/Util/MemoryPool.h"
 #include "KinoSearch/Util/SortUtils.h"
 
-i32_t SortWriter_current_file_format = 2;
+int32_t SortWriter_current_file_format = 3;
 
 static size_t default_mem_thresh = 0x400000; // 4 MB
 
@@ -36,13 +36,14 @@ SortWriter*
 SortWriter_init(SortWriter *self, Schema *schema, Snapshot *snapshot,
                 Segment *segment, PolyReader *polyreader)
 {
-    u32_t field_max = Schema_Num_Fields(schema) + 1;
+    uint32_t field_max = Schema_Num_Fields(schema) + 1;
     DataWriter_init((DataWriter*)self, schema, snapshot, segment, polyreader);
 
-    /* Init. */
+    // Init. 
     self->field_writers   = VA_new(field_max);
     self->counts          = Hash_new(0);
     self->null_ords       = Hash_new(0);
+    self->ord_widths      = Hash_new(0);
     self->temp_ord_out    = NULL;
     self->temp_ix_out     = NULL;
     self->temp_dat_out    = NULL;
@@ -59,6 +60,7 @@ SortWriter_destroy(SortWriter *self)
     DECREF(self->field_writers);
     DECREF(self->counts);
     DECREF(self->null_ords);
+    DECREF(self->ord_widths);
     DECREF(self->temp_ord_out);
     DECREF(self->temp_ix_out);
     DECREF(self->temp_dat_out);
@@ -108,9 +110,9 @@ S_lazy_init_field_writer(SortWriter *self, int32_t field_num)
 
 void
 SortWriter_add_inverted_doc(SortWriter *self, Inverter *inverter, 
-                            i32_t doc_id)
+                            int32_t doc_id)
 {
-    i32_t field_num;
+    int32_t field_num;
 
     Inverter_Iter_Init(inverter);
     while (0 != (field_num = Inverter_Next(inverter))) {
@@ -123,9 +125,8 @@ SortWriter_add_inverted_doc(SortWriter *self, Inverter *inverter,
         }
     }
 
-    /* If our SortFieldWriters have collectively passed the memory threshold,
-     * flush all of them, then release all unique values with a single action.
-     * */
+    // If our SortFieldWriters have collectively passed the memory threshold,
+    // flush all of them, then release all unique values with a single action.
     if (MemPool_Get_Consumed(self->mem_pool) > self->mem_thresh) {
         for (uint32_t i = 0; i < VA_Get_Size(self->field_writers); i++) {
             SortFieldWriter *const field_writer 
@@ -142,7 +143,7 @@ SortWriter_add_segment(SortWriter *self, SegReader *reader, I32Array *doc_map)
 {
     VArray *fields  = Schema_All_Fields(self->schema);
 
-    /* Proceed field-at-a-time, rather than doc-at-a-time. */
+    // Proceed field-at-a-time, rather than doc-at-a-time. 
     for (uint32_t i = 0, max = VA_Get_Size(fields); i < max; i++) {
         CharBuf *field = (CharBuf*)VA_Fetch(fields, i);
         SortReader *sort_reader = (SortReader*)SegReader_Fetch(reader, 
@@ -161,40 +162,6 @@ SortWriter_add_segment(SortWriter *self, SegReader *reader, I32Array *doc_map)
     DECREF(fields);
 }
 
-void
-SortWriter_delete_segment(SortWriter *self, SegReader *reader)
-{
-    Snapshot *snapshot = SortWriter_Get_Snapshot(self);
-    Segment  *segment  = SegReader_Get_Segment(reader);
-    CharBuf  *seg_name = Seg_Get_Name(segment);
-    Hash     *metadata = (Hash*)Seg_Fetch_Metadata_Str(segment, "sort", 4);
-
-    if (metadata) {
-        Hash *counts = (Hash*)CERTIFY(
-            Hash_Fetch_Str(metadata, "counts", 6), HASH);
-        CharBuf *field;
-        Obj     *count;
-
-        /* Delete files for each sorted field. */
-        Hash_Iter_Init(counts);
-        while (Hash_Iter_Next(counts, (Obj**)&field, &count)) {
-            i32_t field_num = Seg_Field_Num(segment, field);
-            CharBuf *ord_file 
-                = CB_newf("%o/sort-%i32.ord", seg_name, field_num);
-            CharBuf *ix_file  
-                = CB_newf("%o/sort-%i32.ix",  seg_name, field_num);
-            CharBuf *dat_file 
-                = CB_newf("%o/sort-%i32.dat", seg_name, field_num);
-            Snapshot_Delete_Entry(snapshot, ord_file);
-            Snapshot_Delete_Entry(snapshot, ix_file);
-            Snapshot_Delete_Entry(snapshot, dat_file);
-            DECREF(ord_file);
-            DECREF(ix_file);
-            DECREF(dat_file);
-        }
-    }
-}
-
 void
 SortWriter_finish(SortWriter *self)
 {
@@ -234,13 +201,16 @@ SortWriter_finish(SortWriter *self)
                 Hash_Store(self->null_ords, (Obj*)field, 
                     (Obj*)CB_newf("%i32", null_ord));
             }
+            int32_t ord_width = SortFieldWriter_Get_Ord_Width(field_writer);
+            Hash_Store(self->ord_widths, (Obj*)field, 
+                (Obj*)CB_newf("%i32", ord_width));
         }
 
         DECREF(field_writer);
     }
     VA_Clear(field_writers);
 
-    /* Store metadata. */
+    // Store metadata. 
     Seg_Store_Metadata_Str(self->segment, "sort", 4,
         (Obj*)SortWriter_Metadata(self));
 
@@ -263,10 +233,11 @@ SortWriter_metadata(SortWriter *self)
     Hash *const metadata  = DataWriter_metadata((DataWriter*)self);
     Hash_Store_Str(metadata, "counts", 6, INCREF(self->counts));
     Hash_Store_Str(metadata, "null_ords", 9, INCREF(self->null_ords));
+    Hash_Store_Str(metadata, "ord_widths", 10, INCREF(self->ord_widths));
     return metadata;
 }
 
-i32_t
+int32_t
 SortWriter_format(SortWriter *self)
 {
     UNUSED_VAR(self);
