@@ -18,26 +18,25 @@
 #include "KinoSearch/Util/Memory.h"
 #include "KinoSearch/Util/StringHelper.h"
 
-/* The end of the string (address of terminating NULL). */
+// The end of the string (address of terminating NULL). 
 #define CBEND(self) ((self)->ptr + (self)->size)
 
-/* Maximum number of characters in a stringified 64-bit integer, including
- * minus sign if negative.
- */
+// Maximum number of characters in a stringified 64-bit integer, including
+// minus sign if negative.
 #define MAX_I64_CHARS 20
 
-/* Helper function for throwing invalid UTF-8 error. Since THROW uses
- * a CharBuf internally, calling THROW with invalid UTF-8 would create an
- * infinite loop -- so we fwrite some of the bogus text to stderr invoke
- * THROW with a generic message. */
+// Helper function for throwing invalid UTF-8 error. Since THROW uses
+// a CharBuf internally, calling THROW with invalid UTF-8 would create an
+// infinite loop -- so we fwrite some of the bogus text to stderr invoke
+// THROW with a generic message.
 static void
 S_die_invalid_utf8(const char *text, size_t size);
 
-/* Helper function for throwing invalid pattern error. */
+// Helper function for throwing invalid pattern error. 
 static void
 S_die_invalid_pattern(const char *pattern);
 
-ZombieCharBuf EMPTY = ZCB_BLANK;
+ZombieCharBuf EMPTY = { ZOMBIECHARBUF, {1}, "", 0, 0 };
 
 CharBuf*
 CB_new(size_t size) 
@@ -49,13 +48,13 @@ CB_new(size_t size)
 CharBuf*
 CB_init(CharBuf *self, size_t size) 
 {
-    /* Derive. */
+    // Derive. 
     self->ptr = (char*)MALLOCATE(size + 1);
 
-     /* Init. */
-    *self->ptr = '\0'; /* Empty string. */
+     // Init. 
+    *self->ptr = '\0'; // Empty string. 
  
-    /* Assign. */
+    // Assign. 
     self->size   = 0;
     self->cap    = size + 1;
 
@@ -75,16 +74,16 @@ CB_new_from_trusted_utf8(const char *ptr, size_t size)
 {
     CharBuf *self = (CharBuf*)VTable_Make_Obj(CHARBUF);
 
-    /* Derive. */
+    // Derive. 
     self->ptr = (char*)MALLOCATE(size + 1);
 
-    /* Copy. */
+    // Copy. 
     memcpy(self->ptr, ptr, size);
 
-    /* Assign. */
+    // Assign. 
     self->size      = size;
     self->cap       = size + 1; 
-    self->ptr[size] = '\0'; /* Null terminate. */
+    self->ptr[size] = '\0'; // Null terminate. 
     
     return self;
 }
@@ -123,37 +122,39 @@ CB_destroy(CharBuf *self)
     SUPER_DESTROY(self, CHARBUF);
 }
 
-i32_t
+int32_t
 CB_hash_code(CharBuf *self)
 {
-    u32_t hashvalue = 5381; 
-    ZombieCharBuf iterator = ZCB_make(self);
+    uint32_t hashvalue = 5381; 
+    ZombieCharBuf *iterator = ZCB_WRAP(self);
     
     {
         const CB_nip_one_t nip_one 
-            = (CB_nip_one_t)METHOD(iterator.vtable, CB, Nip_One);
-        while (iterator.size) {
-            u32_t code_point = (u32_t)nip_one((CharBuf*)&iterator);
+            = (CB_nip_one_t)METHOD(iterator->vtable, CB, Nip_One);
+        while (iterator->size) {
+            uint32_t code_point = (uint32_t)nip_one((CharBuf*)iterator);
             hashvalue = ((hashvalue << 5) + hashvalue) ^ code_point; 
         } 
     }
 
-    return (i32_t) hashvalue;
+    return (int32_t) hashvalue;
 }
 
 static void
 S_grow(CharBuf *self, size_t size)
 {
     if (size >= self->cap) { 
-        self->cap = size + 1;
-        self->ptr = (char*)REALLOCATE(self->ptr, self->cap);
+        CB_Grow(self, size);
     }
 }
 
 char*
 CB_grow(CharBuf *self, size_t size) 
 {
-    if (size >= self->cap) { S_grow(self, size); }
+    if (size >= self->cap) { 
+        self->cap = size + 1;
+        self->ptr = (char*)REALLOCATE(self->ptr, self->cap);
+    }
     return self->ptr;
 }
 
@@ -207,7 +208,7 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
     for ( ; pattern < pattern_end; pattern++) {
         const char *slice_end = pattern;
 
-        /* Consume all characters leading up to a '%'. */
+        // Consume all characters leading up to a '%'. 
         while (slice_end < pattern_end && *slice_end != '%') { slice_end++; }
         if (pattern != slice_end) {
             size_t size = slice_end - pattern;
@@ -216,7 +217,7 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
         }
 
         if (pattern < pattern_end) {
-            pattern++; /* Move past '%'. */
+            pattern++; // Move past '%'. 
 
             switch (*pattern) {
                 case '%': {
@@ -241,19 +242,19 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
                 break;
 
                 case 'i': {
-                    i64_t val = 0;
+                    int64_t val = 0;
                     size_t size;
 
                     if (pattern[1] == '8') {
-                        val = va_arg(args, i32_t);
+                        val = va_arg(args, int32_t);
                         pattern++;
                     }
                     else if (pattern[1] == '3' && pattern[2] == '2') {
-                        val = va_arg(args, i32_t);
+                        val = va_arg(args, int32_t);
                         pattern += 2;
                     }
                     else if (pattern[1] == '6' && pattern[2] == '4') {
-                        val = va_arg(args, i64_t);
+                        val = va_arg(args, int64_t);
                         pattern += 2;
                     }
                     else {
@@ -265,19 +266,19 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
                 break;
 
                 case 'u': {
-                    u64_t val = 0;
+                    uint64_t val = 0;
                     size_t size;
 
                     if (pattern[1] == '8') {
-                        val = va_arg(args, u32_t);
+                        val = va_arg(args, uint32_t);
                         pattern += 1;
                     }
                     else if (pattern[1] == '3' && pattern[2] == '2') {
-                        val = va_arg(args, u32_t);
+                        val = va_arg(args, uint32_t);
                         pattern += 2;
                     }
                     else if (pattern[1] == '6' && pattern[2] == '4') {
-                        val = va_arg(args, u64_t);
+                        val = va_arg(args, uint64_t);
                         pattern += 2;
                     }
                     else {
@@ -303,7 +304,7 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
 
                 case 'x': {
                     if (pattern[1] == '3' && pattern[2] == '2') {
-                        unsigned long val = va_arg(args, u32_t);
+                        unsigned long val = va_arg(args, uint32_t);
                         size_t size = sprintf(buf, "%.8lx", val);
                         CB_Cat_Trusted_Str(self, buf, size);
                         pattern += 2;
@@ -331,9 +332,9 @@ CB_vcatf(CharBuf *self, const char *pattern, va_list args)
                 } 
                 break;
 
-                /* Assume NULL-terminated pattern string, which eliminates the
-                 * need for bounds checking if '%' is the last visible
-                 * character. */
+                // Assume NULL-terminated pattern string, which eliminates the
+                // need for bounds checking if '%' is the last visible
+                // character.
                 default: {
                     S_die_invalid_pattern(pattern_start);
                 }
@@ -349,20 +350,21 @@ CB_to_string(CharBuf *self)
 }
 
 void
-CB_cat_char(CharBuf *self, u32_t code_point)
+CB_cat_char(CharBuf *self, uint32_t code_point)
 {
-    const size_t MIN_SAFE_ROOM = 4;
-    if (self->size + MIN_SAFE_ROOM >= self->cap) { 
-        S_grow(self, Memory_oversize(self->size + MIN_SAFE_ROOM));
+    const size_t MAX_UTF8_BYTES = 4;
+    if (self->size + MAX_UTF8_BYTES >= self->cap) { 
+        S_grow(self, Memory_oversize(self->size + MAX_UTF8_BYTES, 
+            sizeof(char)));
     }
-    self->size += StrHelp_encode_utf8_char(code_point, (u8_t*)CBEND(self));
+    self->size += StrHelp_encode_utf8_char(code_point, (uint8_t*)CBEND(self));
     *CBEND(self) = '\0';
 }
 
-i32_t
-CB_swap_chars(CharBuf *self, u32_t match, u32_t replacement)
+int32_t
+CB_swap_chars(CharBuf *self, uint32_t match, uint32_t replacement)
 {
-    i32_t num_swapped = 0;
+    int32_t num_swapped = 0;
 
     if (match > 127) { 
         THROW(ERR, "match point too high: %u32", match);
@@ -384,33 +386,33 @@ CB_swap_chars(CharBuf *self, u32_t match, u32_t replacement)
     return num_swapped;
 }
 
-i64_t
+int64_t
 CB_to_i64(CharBuf *self) 
 {
     return CB_BaseX_To_I64(self, 10);
 }
 
-i64_t
-CB_basex_to_i64(CharBuf *self, u32_t base)
+int64_t
+CB_basex_to_i64(CharBuf *self, uint32_t base)
 {
-    ZombieCharBuf iterator = ZCB_make(self);
-    i64_t retval = 0;
+    ZombieCharBuf *iterator = ZCB_WRAP(self);
+    int64_t retval = 0;
     bool_t is_negative = false;
 
-    /* Advance past minus sign. */
-    if (ZCB_Code_Point_At(&iterator, 0) == '-') { 
-        ZCB_Nip_One(&iterator);
+    // Advance past minus sign. 
+    if (ZCB_Code_Point_At(iterator, 0) == '-') { 
+        ZCB_Nip_One(iterator);
         is_negative = true;
     }
 
-    /* Accumulate. */
-    while (iterator.size) {
-        i32_t code_point = ZCB_Nip_One(&iterator);
+    // Accumulate. 
+    while (iterator->size) {
+        int32_t code_point = ZCB_Nip_One(iterator);
         if (isalnum(code_point)) {
-            i32_t addend = isdigit(code_point)
-                         ? code_point - '0'
-                         : tolower(code_point) - 'a' + 10;
-            if (addend > (i32_t)base) break;
+            int32_t addend = isdigit(code_point)
+                           ? code_point - '0'
+                           : tolower(code_point) - 'a' + 10;
+            if (addend > (int32_t)base) break;
             retval *= base;
             retval += addend;
         }
@@ -419,7 +421,7 @@ CB_basex_to_i64(CharBuf *self, u32_t base)
         }
     }
 
-    /* Apply minus sign. */
+    // Apply minus sign. 
     if (is_negative) retval = 0 - retval;
 
     return retval;
@@ -507,7 +509,10 @@ void
 CB_cat_trusted_str(CharBuf *self, const char* ptr, size_t size) 
 {
     const size_t new_size = self->size + size;
-    if (new_size >= self->cap) { S_grow(self, Memory_oversize(new_size)); }
+    if (new_size >= self->cap) { 
+        size_t amount = Memory_oversize(new_size, sizeof(char));
+        S_grow(self, amount); 
+    }
     memcpy((self->ptr + self->size), ptr, size);
     self->size = new_size;
     self->ptr[new_size] = '\0';
@@ -517,7 +522,10 @@ void
 CB_cat(CharBuf *self, const CharBuf *other) 
 {
     const size_t new_size = self->size + other->size;
-    if (new_size >= self->cap) { S_grow(self, Memory_oversize(new_size)); }
+    if (new_size >= self->cap) { 
+        size_t amount = Memory_oversize(new_size, sizeof(char));
+        S_grow(self, amount); 
+    }
     memcpy((self->ptr + self->size), other->ptr, other->size);
     self->size = new_size;
     self->ptr[new_size] = '\0';
@@ -551,9 +559,10 @@ CB_equals(CharBuf *self, Obj *other)
     return CB_equals_str(self, evil_twin->ptr, evil_twin->size);
 }
 
-i32_t
+int32_t
 CB_compare_to(CharBuf *self, Obj *other)
 {
+    CERTIFY(other, CHARBUF);
     return CB_compare(&self, &other);
 }
 
@@ -583,28 +592,28 @@ CB_ends_with_str(CharBuf *self, const char *postfix, size_t postfix_len)
     return false;
 }
 
-u32_t
+uint32_t
 CB_trim(CharBuf *self)
 {
     return CB_Trim_Top(self) + CB_Trim_Tail(self);
 }
 
-u32_t
+uint32_t
 CB_trim_top(CharBuf *self)
 {
-    char *ptr   = self->ptr;
-    char *end   = CBEND(self);
-    u32_t count = 0;
+    char     *ptr   = self->ptr;
+    char     *end   = CBEND(self);
+    uint32_t  count = 0;
 
     while (ptr < end) {
-        u32_t code_point = StrHelp_decode_utf8_char(ptr);
+        uint32_t code_point = StrHelp_decode_utf8_char(ptr);
         if (!StrHelp_is_whitespace(code_point)) break;
-        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr];
         count++;
     }
 
     if (count) {
-        /* Copy string backwards. */
+        // Copy string backwards. 
         self->size = CBEND(self) - ptr;
         memmove(self->ptr, ptr, self->size);
     }
@@ -612,15 +621,15 @@ CB_trim_top(CharBuf *self)
     return count;
 }
 
-u32_t
+uint32_t
 CB_trim_tail(CharBuf *self)
 {
-    u32_t         count    = 0;
+    uint32_t      count    = 0;
     const char   *ptr      = CBEND(self);
     char *const   top      = self->ptr; 
 
     while (NULL != (ptr = StrHelp_back_utf8_char(ptr, top))) {
-        u32_t code_point = StrHelp_decode_utf8_char(ptr);
+        uint32_t code_point = StrHelp_decode_utf8_char(ptr);
         if (!StrHelp_is_whitespace(code_point)) break;
         self->size -= (CBEND(self) - ptr);
         count++;
@@ -635,7 +644,7 @@ CB_nip(CharBuf *self, size_t count)
     size_t       num_nipped = 0;
     char *const  end        = CBEND(self);
     char        *ptr        = self->ptr;
-    for ( ; ptr < end  && count--; ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]) {
+    for ( ; ptr < end  && count--; ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr]) {
         num_nipped++;
     }
     self->size = end - ptr;
@@ -643,16 +652,16 @@ CB_nip(CharBuf *self, size_t count)
     return num_nipped;
 }
 
-i32_t
+int32_t
 CB_nip_one(CharBuf *self)
 {
     if (self->size == 0) {
         return 0;
     }
     else {
-        i32_t retval = (i32_t)StrHelp_decode_utf8_char(self->ptr);
-        size_t consumed = StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
-        char *ptr = self->ptr + StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
+        int32_t retval = (int32_t)StrHelp_decode_utf8_char(self->ptr);
+        size_t consumed = StrHelp_UTF8_SKIP[*(uint8_t*)self->ptr];
+        char *ptr = self->ptr + StrHelp_UTF8_SKIP[*(uint8_t*)self->ptr];
         self->size -= consumed;
         memmove(self->ptr, ptr, self->size);
         return retval;
@@ -679,7 +688,7 @@ CB_length(CharBuf *self)
     char   *ptr  = self->ptr; 
     char   *end  = CBEND(self);
     while (ptr < end) {
-        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr];
         len++;
     }
     return len;
@@ -688,21 +697,21 @@ CB_length(CharBuf *self)
 size_t
 CB_truncate(CharBuf *self, size_t count)
 {
-    u32_t num_code_points;
-    ZombieCharBuf iterator = ZCB_make(self);
-    num_code_points = ZCB_Nip(&iterator, count);
-    self->size -= iterator.size;
+    uint32_t num_code_points;
+    ZombieCharBuf *iterator = ZCB_WRAP(self);
+    num_code_points = ZCB_Nip(iterator, count);
+    self->size -= iterator->size;
     return num_code_points;
 }
 
-u32_t
+uint32_t
 CB_code_point_at(CharBuf *self, size_t tick)
 {
     size_t count = 0;
     char *ptr = self->ptr;
     char *const end = CBEND(self);
 
-    for ( ; ptr < end; ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]) {
+    for ( ; ptr < end; ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr]) {
         if (count == tick) return StrHelp_decode_utf8_char(ptr);
         count++;
     }
@@ -710,7 +719,7 @@ CB_code_point_at(CharBuf *self, size_t tick)
     return 0;
 }
 
-u32_t
+uint32_t
 CB_code_point_from(CharBuf *self, size_t tick)
 {
     size_t      count = 0;
@@ -726,14 +735,14 @@ CB_code_point_from(CharBuf *self, size_t tick)
 CharBuf*
 CB_substring(CharBuf *self, size_t offset, size_t len)
 {
-    ZombieCharBuf iterator = ZCB_make(self);
+    ZombieCharBuf *iterator = ZCB_WRAP(self);
     char *sub_start;
     size_t byte_len;
 
-    ZCB_Nip(&iterator, offset);
-    sub_start = iterator.ptr;
-    ZCB_Nip(&iterator, len);
-    byte_len = iterator.ptr - sub_start;
+    ZCB_Nip(iterator, offset);
+    sub_start = iterator->ptr;
+    ZCB_Nip(iterator, len);
+    byte_len = iterator->ptr - sub_start;
 
     return CB_new_from_trusted_utf8(sub_start, byte_len);
 }
@@ -743,16 +752,16 @@ CB_compare(const void *va, const void *vb)
 {
     const CharBuf *a = *(const CharBuf**)va;
     const CharBuf *b = *(const CharBuf**)vb;
-    ZombieCharBuf iterator_a = ZCB_make(a);
-    ZombieCharBuf iterator_b = ZCB_make(b);
-    while (iterator_a.size && iterator_b.size) {
-        i32_t code_point_a = ZCB_Nip_One(&iterator_a);
-        i32_t code_point_b = ZCB_Nip_One(&iterator_b);
-        const i32_t comparison = code_point_a - code_point_b;
+    ZombieCharBuf *iterator_a = ZCB_WRAP(a);
+    ZombieCharBuf *iterator_b = ZCB_WRAP(b);
+    while (iterator_a->size && iterator_b->size) {
+        int32_t code_point_a = ZCB_Nip_One(iterator_a);
+        int32_t code_point_b = ZCB_Nip_One(iterator_b);
+        const int32_t comparison = code_point_a - code_point_b;
         if (comparison != 0) return comparison;
     }
-    if (iterator_a.size != iterator_b.size) {
-        return iterator_a.size < iterator_b.size ? -1 : 1;
+    if (iterator_a->size != iterator_b->size) {
+        return iterator_a->size < iterator_b->size ? -1 : 1;
     }
     return 0;
 }
@@ -767,8 +776,8 @@ void
 CB_set_size(CharBuf *self, size_t size) { self->size = size;  }
 size_t
 CB_get_size(CharBuf *self)              { return self->size; }
-u8_t*
-CB_get_ptr8(CharBuf *self)            { return (u8_t*)self->ptr; }
+uint8_t*
+CB_get_ptr8(CharBuf *self)              { return (uint8_t*)self->ptr; }
 
 /*****************************************************************/
 
@@ -799,8 +808,8 @@ ViewCB_init(ViewCharBuf *self, const char *utf8, size_t size)
 void
 ViewCB_destroy(ViewCharBuf *self)
 {
-    /* Note that we do not free self->ptr, and that we invoke the
-     * SUPER_DESTROY with CHARBUF instead of VIEWCHARBUF. */
+    // Note that we do not free self->ptr, and that we invoke the
+    // SUPER_DESTROY with CHARBUF instead of VIEWCHARBUF.
     SUPER_DESTROY(self, CHARBUF);
 }
 
@@ -820,17 +829,17 @@ ViewCB_assign_str(ViewCharBuf *self, const char *utf8, size_t size)
     self->size = size;
 }
 
-u32_t
+uint32_t
 ViewCB_trim_top(ViewCharBuf *self)
 {
-    u32_t  count  = 0;
-    char  *ptr    = self->ptr;
-    char  *end    = CBEND(self);
+    uint32_t  count = 0;
+    char     *ptr   = self->ptr;
+    char     *end   = CBEND(self);
 
     while (ptr < end) {
-        u32_t code_point = StrHelp_decode_utf8_char(ptr);
+        uint32_t code_point = StrHelp_decode_utf8_char(ptr);
         if (!StrHelp_is_whitespace(code_point)) break;
-        ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr];
+        ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr];
         count++;
     }
 
@@ -850,7 +859,7 @@ ViewCB_nip(ViewCharBuf *self, size_t count)
     char   *end    = CBEND(self);
     for (num_nipped = 0; 
          ptr < end && count--; 
-         ptr += StrHelp_UTF8_SKIP[*(u8_t*)ptr]
+         ptr += StrHelp_UTF8_SKIP[*(uint8_t*)ptr]
     ) {
         num_nipped++;
     }
@@ -859,47 +868,85 @@ ViewCB_nip(ViewCharBuf *self, size_t count)
     return num_nipped;
 }
 
-i32_t
+int32_t
 ViewCB_nip_one(ViewCharBuf *self)
 {
     if (self->size == 0) {
         return 0;
     }
     else {
-        i32_t retval = (i32_t)StrHelp_decode_utf8_char(self->ptr);
-        size_t consumed = StrHelp_UTF8_SKIP[*(u8_t*)self->ptr];
+        int32_t retval = (int32_t)StrHelp_decode_utf8_char(self->ptr);
+        size_t consumed = StrHelp_UTF8_SKIP[*(uint8_t*)self->ptr];
         self->ptr  += consumed;
         self->size -= consumed;
         return retval;
     }
 }
 
-void
+char*
 ViewCB_grow(ViewCharBuf *self, size_t size)
 {
-    UNUSED_VAR(self);
     UNUSED_VAR(size);
     THROW(ERR, "Can't grow a ViewCharBuf ('%o')", self);
+    UNREACHABLE_RETURN(char*);
 }
 
 /*****************************************************************/
 
-ZombieCharBuf
-ZCB_make_str(const char *ptr, size_t size) 
+ZombieCharBuf*
+ZCB_new(void *allocation)
 {
-    ZombieCharBuf retval;
-    retval.ref.count    = 1;
-    retval.vtable       = ZOMBIECHARBUF;
-    retval.cap          = 0;
-    retval.size         = size;
-    retval.ptr          = (char*)ptr;
-    return retval;
+    static char empty_string[] = "";
+    ZombieCharBuf *self = (ZombieCharBuf*)allocation;
+    self->ref.count    = 1;
+    self->vtable       = ZOMBIECHARBUF;
+    self->cap          = 0;
+    self->size         = 0;
+    self->ptr          = empty_string;
+    return self;
 }
 
-ZombieCharBuf
-ZCB_make(const CharBuf *source) 
+ZombieCharBuf*
+ZCB_newf(void *allocation, size_t alloc_size, const char *pattern, ...)
 {
-    return ZCB_make_str(source->ptr, source->size);
+    ZombieCharBuf *self = (ZombieCharBuf*)allocation;
+
+    self->ref.count    = 1;
+    self->vtable       = ZOMBIECHARBUF;
+    self->cap          = alloc_size - sizeof(ZombieCharBuf);
+    self->size         = 0;
+    self->ptr          = ((char*)allocation) + sizeof(ZombieCharBuf);
+
+    va_list args;
+    va_start(args, pattern);
+    ZCB_VCatF(self, pattern, args);
+    va_end(args);
+
+    return self;
+}
+
+ZombieCharBuf*
+ZCB_wrap_str(void *allocation, const char *ptr, size_t size)
+{
+    ZombieCharBuf *self = (ZombieCharBuf*)allocation;
+    self->ref.count    = 1;
+    self->vtable       = ZOMBIECHARBUF;
+    self->cap          = 0;
+    self->size         = size;
+    self->ptr          = (char*)ptr;
+    return self;
+}
+
+ZombieCharBuf*
+ZCB_wrap(void *allocation, const CharBuf *source)
+{
+    return ZCB_wrap_str(allocation, source->ptr, source->size);
+}
+
+size_t
+ZCB_size()
+{
+    return sizeof(ZombieCharBuf);
 }
 
 void
