@@ -4,22 +4,22 @@
 #include "KinoSearch/Search/Compiler.h"
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Index/DocVector.h"
-#include "KinoSearch/Schema.h"
+#include "KinoSearch/Index/Similarity.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Matcher.h"
 #include "KinoSearch/Search/Query.h"
-#include "KinoSearch/Search/Searchable.h"
-#include "KinoSearch/Search/Similarity.h"
+#include "KinoSearch/Search/Searcher.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
 #include "KinoSearch/Util/Freezer.h"
 
 Compiler*
-Compiler_init(Compiler *self, Query *parent, Searchable *searchable,
+Compiler_init(Compiler *self, Query *parent, Searcher *searcher,
             Similarity *sim, float boost)
 {
     Query_init((Query*)self, boost);
     if (!sim) {
-        Schema *schema = Searchable_Get_Schema(searchable);
+        Schema *schema = Searcher_Get_Schema(searcher);
         sim = Schema_Get_Similarity(schema);
     }
     self->parent  = (Query*)INCREF(parent);
@@ -64,22 +64,22 @@ Compiler_apply_norm_factor(Compiler *self, float factor)
 void
 Compiler_normalize(Compiler *self)
 {
-    /* factor = ( tf_q * idf_t ) */
+    // factor = ( tf_q * idf_t ) 
     float factor = Compiler_Sum_Of_Squared_Weights(self); 
 
-    /* factor /= norm_q */
+    // factor /= norm_q 
     factor = Sim_Query_Norm(self->sim, factor);
 
-    /* weight *= factor */
+    // weight *= factor 
     Compiler_Apply_Norm_Factor(self, factor); 
 }
 
 VArray*
-Compiler_highlight_spans(Compiler *self, Searchable *searchable, 
+Compiler_highlight_spans(Compiler *self, Searcher *searcher, 
                        DocVector *doc_vec, const CharBuf *field)
 {
     UNUSED_VAR(self);
-    UNUSED_VAR(searchable);
+    UNUSED_VAR(searcher);
     UNUSED_VAR(doc_vec);
     UNUSED_VAR(field);
     return VA_new(0);
@@ -101,7 +101,7 @@ Compiler_equals(Compiler *self, Obj *other)
 {
     Compiler *evil_twin = (Compiler*)other;
     if (evil_twin == self) return true;
-    if (!OBJ_IS_A(evil_twin, COMPILER)) return false;
+    if (!Obj_Is_A(other, COMPILER)) return false;
     if (self->boost != evil_twin->boost) return false;
     if (!Query_Equals(self->parent, (Obj*)evil_twin->parent)) return false;
     if (!Sim_Equals(self->sim, (Obj*)evil_twin->sim)) return false;
@@ -127,7 +127,7 @@ Compiler_deserialize(Compiler *self, InStream *instream)
     return self;
 }
 
-/* Copyright 2006-2009 Marvin Humphrey
+/* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
