@@ -24,13 +24,13 @@ test_Dump_And_Load(TestBatch *batch)
 void
 TestPhraseQuery_run_tests()
 {
-    TestBatch *batch = Test_new_batch("TestPhraseQuery", 1, NULL);
-    PLAN(batch);
+    TestBatch *batch = TestBatch_new(1);
+    TestBatch_Plan(batch);
     test_Dump_And_Load(batch);
-    batch->destroy(batch);
+    DECREF(batch);
 }
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
