@@ -1,3 +1,4 @@
+package KinoSearch::Index::DocReader;
 use KinoSearch;
 
 1;
@@ -8,10 +9,10 @@ __BINDING__
 
 my $synopsis = <<'END_SYNOPSIS';
     my $doc_reader = $seg_reader->obtain("KinoSearch::Index::DocReader");
-    my $doc        = $doc_reader->fetch($doc_id);
+    my $doc        = $doc_reader->fetch( doc_id => $doc_id );
 END_SYNOPSIS
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Index::DocReader",
     bind_constructors => ["new"],
@@ -21,7 +22,7 @@ Boilerplater::Binding::Perl::Class->register(
         methods  => [qw( fetch aggregator )],
     },
 );
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Index::DefaultDocReader",
     bind_constructors => ["new"],
@@ -29,7 +30,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
