@@ -1,12 +1,11 @@
+package KinoSearch::Search::SortSpec;
 use KinoSearch;
 
 1;
 
 __END__
 
-
-__AUTO_XS__
-
+__BINDING__
 
 my $synopsis = <<'END_SYNOPSIS';
     my $sort_spec = KinoSearch::Search::SortSpec->new(
@@ -25,19 +24,20 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $sort_spec = KinoSearch::Search::SortSpec->new( rules => \@rules );
 END_CONSTRUCTOR
 
-{   "KinoSearch::Search::SortSpec" => {
-        bind_methods      => [qw( Get_Rules )],
-        make_constructors => ["new"],
-        make_pod          => {
-            synopsis    => $synopsis,
-            constructor => { sample => $constructor },
-        },
+Clownfish::Binding::Perl::Class->register(
+    parcel            => "KinoSearch",
+    class_name        => "KinoSearch::Search::SortSpec",
+    bind_methods      => [qw( Get_Rules )],
+    bind_constructors => ["new"],
+    make_pod          => {
+        synopsis    => $synopsis,
+        constructor => { sample => $constructor },
     },
-}
+);
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
